"""Drop `db` column from table `environment`.

Reason:
The API does not have to store which tracker database the various environments are
using. This information is passed to the Rasa environments through the Docker setup.
Hence, the `db` column can be dropped from the `environment` table.

Revision ID: e4ac66862c8c
Revises: 

"""
from alembic import op
import sqlalchemy as sa

import rasax.community.database.schema_migrations.alembic.utils as alembic_utils

# revision identifiers, used by Alembic.
revision = "e4ac66862c8c"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # Since this is the first migration it could be the case that we are initializing
    # a fresh database which needs no migration. Hence, we have to check whether the
    # migration is actually necessary.
    if alembic_utils.table_has_column("environment", "db"):
        # Use batch operation to drop column since sqlite `ALTER` does not support
        # dropping columns
        with op.batch_alter_table("environment") as batch_op:
            batch_op.drop_column("db")


def downgrade():
    # Use batch operation to add column since sqlite does not support `ALTER` support
    with op.batch_alter_table("environment") as batch_op:
        batch_op.add_column(sa.Column("db", sa.String))
